#include <iostream>
#include <fstream>

#include <string.h>

using namespace std;

typedef unsigned long DWORD;
typedef unsigned short int WORD;
typedef unsigned char BYTE;

#define PRO2TEXT 1
#define TEXT2PRO 2

#define ITEM    0
#define CRITTER 1
#define SCENERY 2
#define WALL    3
#define TILE    4
#define MISC    5

char* lpszObjectType[] = {
    "Item",
    "Critter",
    "Scenery",
    "Wall",
    "Tile",
    "Misc",
    "Unknown!!!"
};

#define ARMOR       0
#define CONTAINER   1
#define DRUG        2
#define WEAPON      3
#define AMMO        4
#define MISCITEM    5
#define KEY         6

char* lpszItemType[] = {
    "Armor",
    "Container",
    "Drug",
    "Weapon",
    "Ammo",
    "Misc Item",
    "Key",
    "Unknown!!!"
};

#define PORTAL          0
#define STAIRS          1
#define ELEVATORS       2
#define LADDERBOTTOM    3
#define LADDERTOP       4
#define GENERICSCENERY  5

char* lpszSceneryType[] = {
    "Portal",
    "Stairs",
    "Elevators",
    "Ladder Bottom",
    "Ladder Top",
    "Generic Scenery",
    "Unknown!!!"
};

void ReverseWord(WORD& w)
{
    w = (w >> 8) | (w << 8);
}

void ReverseDWord(DWORD& dw)
{
    dw = (dw >> 24) | (dw << 24) | ((dw >> 8) & 0x0000FF00) | ((dw << 8) & 0x00FF0000);
}

int main(int argc, char* argv[])
{
    if (argc != 4) {
        cerr << "Usage:\tprocvt.exe file.pro file.txt /pt\n"
                "\tor\n"
                "\tprocvt.exe file.txt file.pro /tp\n";
        return 1;
    }

    strlwr(argv[3]);

    BYTE nCvtType = 0;

    if (!strcmp(argv[3], "/pt")) nCvtType = PRO2TEXT;
    else if (!strcmp(argv[3], "/tp")) nCvtType = TEXT2PRO;

    if (nCvtType == 0) {
        cerr << "Wrong conversion type!\n";
        return 2;
    }

    ifstream in;
    ofstream out;

    if (nCvtType == PRO2TEXT) {
        in.open(argv[1], ios::binary);
        out.open(argv[2]);
    }
    else {
        in.open(argv[1]);
        out.open(argv[2], ios::binary);
    }

    DWORD dwValue;
    BYTE  nValue;
    BYTE  nObjectType;
    DWORD dwFileSize;

    in.seekg(0, ios::end);
    dwFileSize = in.tellg();
    in.seekg(0);

    // Pro ID
    if (nCvtType == PRO2TEXT) {
        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
        ReverseDWord(dwValue);
    }
    else {
        in >> dwValue;
    }
    nObjectType = BYTE(dwValue >> 24);
    nObjectType = (nObjectType > 5) ? 6 : nObjectType;
    if (nCvtType == PRO2TEXT) {
        out << dwValue << endl;
    }
    else {
        ReverseDWord(dwValue);
        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
    }

    // Description ID
    if (nCvtType == PRO2TEXT) {
        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
        ReverseDWord(dwValue);
        out << dwValue << endl;
    }
    else {
        in >> dwValue;
        ReverseDWord(dwValue);
        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
    }

    // Item FRMID
    if (nCvtType == PRO2TEXT) {
        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
        ReverseDWord(dwValue);
        out << dwValue << endl;
    }
    else {
        in >> dwValue;
        ReverseDWord(dwValue);
        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
    }

    switch(nObjectType) {
        case ITEM:
            // 0x0C
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x10
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // Flags
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x18
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x1c
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // Item Type
            DWORD dwItemType;

            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
            }
            else {
                in >> dwValue;
            }
            dwItemType = dwValue;
            dwItemType = (dwItemType > 6) ? 7 : dwItemType;
            if (nCvtType == PRO2TEXT) {
                out << dwValue << endl;
            }
            else {
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // Material ID
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x28
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // Weight
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // Price
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // Inventory FRMID
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x38
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&nValue), sizeof(nValue));
                out << nValue << endl;
            }
            else {
                in >> nValue;
                out.write(reinterpret_cast<char*>(&nValue), sizeof(nValue));
            }

            switch(dwItemType) {
                case ARMOR:
                    // Armor class
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // Damage resistance
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // Damage treshold
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // Perk ID
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // Player Female FRMID
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // Player Male FRMID
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    break;

                case CONTAINER:
                    // Capacity
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x3d
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    break;

                case DRUG:
                    // StatID0
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // StatID1
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // StatID2
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // Immediate stat modifiers
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // Intermediate effect delay
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // Intermediate stat modifiers
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // End effect delay
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // End stat modifiers
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // Addiction rate
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // Addiction PerkID
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // Addiction Delay
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    break;

                case WEAPON:
                    // 0x39
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x3d
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x41
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x45
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x49
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x4d
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x51
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x55
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x59
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x5d
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x61
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x65
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x69
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x6d
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x71
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x75
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x79
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    break;

                case AMMO:
                    // 0x39
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x3d
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x41
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x45
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x49
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x4d
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    break;

                case MISCITEM:
                    // 0x39
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x3d
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x41
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    break;

                case KEY:
                    // 0x39
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    break;

                default:
                    cerr << "Unknown item type!!!\n";
                    return 3;
            };

            break;

        case CRITTER:
            // 0x0C
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x10
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x14
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x18
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x1C
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x20
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x24
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x28
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x2C
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x30-0xbb
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0xbc-0x147
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x148-0x18f
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // Body Type ID
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // Expirience points
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // Kill type name ID
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x19C
            if (dwFileSize == 416) {
                if (nCvtType == PRO2TEXT) {
                    in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    ReverseDWord(dwValue);
                    out << dwValue << endl;
                }
                else {
                    in >> dwValue;
                    ReverseDWord(dwValue);
                    out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                }
            }
            break;

        case SCENERY:
            // 0x0C
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x10
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x14
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x18
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x1c
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x20
            DWORD dwSceneryType;

            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
            }
            else {
                in >> dwValue;
            }
            dwSceneryType = dwValue;
            dwSceneryType = (dwSceneryType > 5) ? 6 : dwSceneryType;
            if (nCvtType == PRO2TEXT) {
                out << dwValue << endl;
            }
            else {
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // Material ID
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x28
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&nValue), sizeof(nValue));
                out << nValue << endl;
            }
            else {
                in >> nValue;
                out.write(reinterpret_cast<char*>(&nValue), sizeof(nValue));
            }

            switch(dwSceneryType) {
                case PORTAL:
                    // 0x29
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x2d
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    break;

                case STAIRS:
                    // 0x29
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x2d
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    break;

                case ELEVATORS:
                    // 0x29
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }

                    // 0x2d
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    break;

                case LADDERBOTTOM:
                    // 0x29
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    break;

                case LADDERTOP:
                    // 0x29
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    break;

                case GENERICSCENERY:
                    // 0x29
                    if (nCvtType == PRO2TEXT) {
                        in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                        ReverseDWord(dwValue);
                        out << dwValue << endl;
                    }
                    else {
                        in >> dwValue;
                        ReverseDWord(dwValue);
                        out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                    }
                    break;

                default:
                    cerr << "Unknow scenery type!!!\n";
                    return 4;
            }

            break;

        case WALL:
            // 0x0C
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x10
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x14
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x18
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x1c
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // Material ID
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            break;

        case TILE:
            // 0x0C
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x10
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x14
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x18
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            break;

        case MISC:
            // 0x0C
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x10
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x14
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }

            // 0x18
            if (nCvtType == PRO2TEXT) {
                in.read(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
                ReverseDWord(dwValue);
                out << dwValue << endl;
            }
            else {
                in >> dwValue;
                ReverseDWord(dwValue);
                out.write(reinterpret_cast<char*>(&dwValue), sizeof(dwValue));
            }
            break;

        default:
            cerr << "Unknown object type!!!\n";
            return 5;
    }

    return 0;
}

